summaryrefslogtreecommitdiffstats
path: root/kicker/menuext/tom
diff options
context:
space:
mode:
Diffstat (limited to 'kicker/menuext/tom')
-rw-r--r--kicker/menuext/tom/README2
-rw-r--r--kicker/menuext/tom/TASKGROUPS2
-rw-r--r--kicker/menuext/tom/tom.cc22
3 files changed, 13 insertions, 13 deletions
diff --git a/kicker/menuext/tom/README b/kicker/menuext/tom/README
index 8cc07d507..2616c76c5 100644
--- a/kicker/menuext/tom/README
+++ b/kicker/menuext/tom/README
@@ -58,7 +58,7 @@ What should be the default task entry format be:
a) Task Name
b) Task Name (App Name)
c) App Name (Task Name) <-- silly option =)
-Should "Run A Command..." be tqreplaced by an inline combobox?
+Should "Run A Command..." be replaced by an inline combobox?
Pros: It's more obvious and will work even if kdesktop is gone. The widget
is already written (in tom.cc)
Cons: It makes it stand out too much over other entries, takes up more room
diff --git a/kicker/menuext/tom/TASKGROUPS b/kicker/menuext/tom/TASKGROUPS
index 1cb8a41b9..c1aa1ed98 100644
--- a/kicker/menuext/tom/TASKGROUPS
+++ b/kicker/menuext/tom/TASKGROUPS
@@ -7,7 +7,7 @@ of tasks in the group (NumTasks) and optionally whether or not it is hidden
(Hidden).
For each task there is a numbered section in the file in the form TaskN. Each
-section tqcontains the user visible name for the task (Name), the associated
+section contains the user visible name for the task (Name), the associated
.desktop file and optionally whether or not it is hidden (Hidden).
An example file can be found below.
diff --git a/kicker/menuext/tom/tom.cc b/kicker/menuext/tom/tom.cc
index 7ec080a8b..3a4ebf4ed 100644
--- a/kicker/menuext/tom/tom.cc
+++ b/kicker/menuext/tom/tom.cc
@@ -109,7 +109,7 @@ class runMenuWidget : public TQWidget, public QMenuItem
l2->setBuddy(this);
runLayout->addWidget(l2);*/
m_runEdit = new KHistoryCombo(this);
- m_runEdit->tqsetSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Preferred);
+ m_runEdit->setSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Preferred);
runLayout->addWidget(m_runEdit, 10);
runLayout->addSpacing(KDialog::spacingHint());
@@ -143,7 +143,7 @@ class runMenuWidget : public TQWidget, public QMenuItem
TQPainter p(this);
TQRect r(rect());
// ew, nasty hack. may result in coredumps due to horrid C-style cast???
- kapp->style().tqdrawControl(TQStyle::CE_PopupMenuItem, &p, m_menu, r, palette().active(), TQStyle::Style_Enabled,
+ kapp->style().drawControl(TQStyle::CE_PopupMenuItem, &p, m_menu, r, palette().active(), TQStyle::Style_Enabled,
TQStyleOption(static_cast<TQMenuItem*>(this), 0, KIcon::SizeMedium ));
p.drawPixmap(KDialog::spacingHint(), 1, icon);
p.drawText((KDialog::spacingHint() * 2) + KIcon::SizeMedium, textRect.height() + ((height() - textRect.height()) / 2), i18n("Run:"));
@@ -239,7 +239,7 @@ void TOM::initializeRecentDocs()
KDesktopFile f(*it, true /* read only */);
m_recentDocsMenu->insertItem(DesktopIcon(f.readIcon(), KIcon::SizeMedium),
- f.readName().tqreplace('&', "&&"), id);
+ f.readName().replace('&', "&&"), id);
++id;
}
}
@@ -301,8 +301,8 @@ int TOM::appendTaskGroup(KConfig& config, bool inSubMenu)
}
TQString name = config.readEntry("Name");
- // in case the name tqcontains an ampersand, double 'em up
- name.tqreplace("&", "&&");
+ // in case the name contains an ampersand, double 'em up
+ name.replace("&", "&&");
TQString desktopfile = config.readPathEntry("DesktopFile");
KService::Ptr pService = KService::serviceByDesktopPath(desktopfile);
@@ -655,7 +655,7 @@ bool TOM::loadSidePixmap()
// limit max/min brightness
int r, g, b;
color.rgb(&r, &g, &b);
- int gray = tqGray(r, g, b);
+ int gray = qGray(r, g, b);
if (gray > 180) {
r = (r - (gray - 180) < 0 ? 0 : r - (gray - 180));
g = (g - (gray - 180) < 0 ? 0 : g - (gray - 180));
@@ -736,13 +736,13 @@ void TOM::setMaximumSize(int w, int h)
TQRect TOM::sideImageRect()
{
- return TQStyle::tqvisualRect( TQRect( frameWidth(), frameWidth(), m_sidePixmap.width(),
+ return TQStyle::visualRect( TQRect( frameWidth(), frameWidth(), m_sidePixmap.width(),
height() - 2*frameWidth() ), this );
}
void TOM::resizeEvent(TQResizeEvent * e)
{
- setFrameRect( TQStyle::tqvisualRect( TQRect( m_sidePixmap.width(), 0,
+ setFrameRect( TQStyle::visualRect( TQRect( m_sidePixmap.width(), 0,
width() - m_sidePixmap.width(), height() ), this ) );
}
@@ -757,7 +757,7 @@ void TOM::paintEvent(TQPaintEvent * e)
style().drawPrimitive( TQStyle::PE_PanelPopup, &p,
TQRect( 0, 0, width(), height() ),
- tqcolorGroup(), TQStyle::Style_Default,
+ colorGroup(), TQStyle::Style_Default,
TQStyleOption( frameWidth(), 0 ) );
TQRect r = sideImageRect();
@@ -775,7 +775,7 @@ TQMouseEvent TOM::translateMouseEvent( TQMouseEvent* e )
{
TQRect side = sideImageRect();
- if ( !side.tqcontains( e->pos() ) )
+ if ( !side.contains( e->pos() ) )
return *e;
TQPoint newpos( e->pos() );
@@ -824,7 +824,7 @@ void TOM::runCommand()
void TOM::runTask(int id)
{
- if (!m_tasks.tqcontains(id)) return;
+ if (!m_tasks.contains(id)) return;
kapp->propagateSessionManager();
KApplication::startServiceByDesktopPath(m_tasks[id]->desktopEntryPath(),